Bibliography
============

.. _HDFG1:

:ref:`[HDFG1] <HDFG1>`
    The HDF Group. What is HDF5?. Concise description about HDF5 capabilities
    and its differences from earlier versions (HDF4).
    `<http://www.hdfgroup.org/HDF5/whatishdf5.html>`_.

.. _HDFG2:

:ref:`[HDFG2] <HDFG2>`
    The HDF Group. Introduction to HDF5. Introduction to the HDF5 data model
    and programming model. `<http://www.hdfgroup.org/HDF5/doc/H5.intro.html>`_.

.. _HDFG3:

:ref:`[HDFG3] <HDFG3>`
    The HDF Group. The HDF5 table programming model. Examples on using HDF5
    tables with the C API. `<http://www.hdfgroup.org/HDF5/Tutor/h5table.html>`_.

.. _MERTZ:

:ref:`[MERTZ] <MERTZ>`
    David Mertz. Objectify. On the 'Pythonic' treatment of XML documents as
    objects(II). Article describing XML Objectify, a Python module that
    allows working with XML documents as Python objects.
    Some of the ideas presented here are used in PyTables.
    `<http://gnosis.cx/publish/programming/xml_matters_2.html>`_.

.. _CYTHON:

:ref:`[CYTHON] <CYTHON>`
    Stefan Behnel, Robert Bradshaw, Dag Sverre Seljebotn, and Greg Ewing.
    Cython. A language that makes writing C extensions for the Python
    language as easy as Python itself. `<http://www.cython.org>`_.

.. _NUMPY:

:ref:`[NUMPY] <NUMPY>`
    Travis Oliphant and et al. NumPy. Scientific Computing with Numerical
    Python. The latest and most powerful re-implementation of Numeric to
    date.
    It implements all the features that can be found in Numeric and numarray,
    plus a bunch of new others. In general, it is more efficient as well.
    `<http://www.numpy.org>`_.

.. _NUMEXPR:

:ref:`[NUMEXPR] <NUMEXPR>`
    David Cooke, Francesc Alted, and et al. Numexpr. Fast evaluation of array
    expressions by using a vector-based virtual machine.
    It is an enhaced computing kernel that is generally faster (between 1x
    and 10x, depending on the kind of operations) than NumPy at evaluating
    complex array expressions. `<http://code.google.com/p/numexpr>`_.

.. _ZLIB:

:ref:`[ZLIB] <ZLIB>`
    JeanLoup Gailly and Mark Adler. zlib. A Massively Spiffy Yet Delicately
    Unobtrusive Compression Library. A standard library for compression
    purposes. `<http://www.gzip.org/zlib/>`_.

.. _LZO:

:ref:`[LZO] <LZO>`
    Markus F Oberhumer. LZO. A data compression library which is suitable for
    data de-/compression in real-time. It offers pretty fast compression and
    decompression with reasonable compression ratio.
    `<http://www.oberhumer.com/opensource/>`_.

.. _BZIP2:

:ref:`[BZIP2] <BZIP2>`
    Julian Seward. bzip2. A high performance lossless compressor.
    It offers very high compression ratios within reasonable times.
    `<http://www.bzip.org/>`_.

.. _BLOSC:

:ref:`[BLOSC] <BLOSC>`
    Francesc Alted. Blosc. A blocking, shuffling and loss-less compression
    library.  A compressor designed to transmit data from memory to CPU
    (and back) faster than a plain memcpy().
    `<http://www.blosc.org/>`_.

.. _GNUWIN32:

:ref:`[GNUWIN32] <GNUWIN32>`
    Alexis Wilke, Jerry S., Kees Zeelenberg, and Mathias Michaelis.
    GnuWin32. GNU (and other) tools ported to Win32.
    GnuWin32 provides native Win32-versions of GNU tools, or tools with a
    similar open source licence.
    `<http://gnuwin32.sourceforge.net/>`_.

.. _PSYCO:

:ref:`[PYSCO] <PSYCO>`
    Armin Rigo. Psyco. A Python specializing compiler.
    Run existing Python software faster, with no change in your source.
    `<http://psyco.sourceforge.net>`_.

.. _SCIPY1:

:ref:`[SCIPY1] <SCIPY1>`
    Konrad Hinsen. Scientific Python. Collection of Python modules useful for
    scientific computing.
    `<http://dirac.cnrs-orleans.fr/ScientificPython>`_.

.. _SCIPY2:

:ref:`[SCIPY2] <SCIPY2>`
    Eric Jones, Travis Oliphant, Pearu Peterson, and et al. SciPy.
    Scientific tools for Python. SciPy supplements the popular Numeric module,
    gathering a variety of high level science and engineering modules
    together as a single package.
    `<http://www.scipy.org>`_.

.. _OPTIM:

:ref:`[OPTIM] <OPTIM>`
    Francesc Alted and Ivan Vilata. Optimization of file openings in PyTables.
    This document explores the savings of the opening process in terms of
    both CPU time and memory, due to the adoption of a LRU cache for the
    nodes in the object tree.
    `<http://www.pytables.org/docs/NewObjectTreeCache.pdf>`_.

.. _OPSI:

:ref:`[OPSI] <OPSI>`
    Francesc Alted and Ivan Vilata. OPSI: The indexing system of PyTables 2
    Professional Edition. Exhaustive description and benchmarks about the
    indexing engine that comes with PyTables Pro.
    `<http://www.pytables.org/docs/OPSI-indexes.pdf>`_.

.. _VITABLES:

:ref:`[VITABLES] <VITABLES>`
    Vicent Mas. ViTables. A GUI for PyTables/HDF5 files.
    It is a graphical tool for browsing and editing files in both PyTables
    and HDF5 formats.
    `<http://vitables.org>`_.

.. _GIT:

:ref:`[GIT] <GIT>`
    Git is a free and open source, distributed version control system designed
    to handle everything from small to very large projects with speed and
    efficiency `<http://git-scm.com>`_.

.. _SPHINX:

:ref:`[SPHINX] <SPHINX>`
    Sphinx is a tool that makes it easy to create intelligent and beautiful
    documentation, written by Georg Brandl and licensed under the BSD license
    `<http://sphinx-doc.org>`_.

.. |Kuepper| unicode:: K U+00FC pper .. Kuepper

.. todo:: remove the above substitution. It is no more needed with sphinx
          1.0.8
